/*
  machine.cpp
  Copyright (C) 2010 Tomohiro Masubuchi <bucchi@e-ml.jp>

  This file is part of qgmap.

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; If not, see <http://www.gnu.org/licenses/>.
*/

#include "qgmap.h"
#include "machine.h"
#include <qfile.h>
#include <qstring.h>
#include <qapplication.h>

Machine::Machine(void)
{
#ifdef QWS
	QFile info("/proc/cpuinfo");
	QString line;
	int ret;

	type_ = SL_C;

	if (! info.open(IO_ReadOnly))
		return;

	ret = info.readLine(line, 256);
	info.close();

	if (ret < 0)
		return;

	if (line.find("PXA210") >= 0) {
		/* SL-A300 */
		type_ = SL_A300;
	}
#else
	type_ = PC;
#endif
}

Machine::~Machine()
{
}

MachineType Machine::type()
{
	return type_;
}

Resolution Machine::resolution()
{
	return qApp->desktop()->size().height() < 480 ? QVGA: VGA;
}

void Machine::setGlobalDefaults()
{
	switch (type_) {
	case SL_C:
		g_db_poi = "/home/zaurus/Settings/qgmap-poi.db";
		break;

	case SL_A300:
		g_db_poi = "/mnt/card/qgmap-poi.db";
		break;

	case PC:
		g_db_poi = "test.db";
		break;
	}
}

QSize Machine::screensize()
{
	if (!qApp)
		return QSize(0,0);
	return qApp->desktop()->size();
}

int Machine::screenShortLen()
{
#ifdef QWS
	QSize size = screensize();
	return MIN(size.height(), size.width());
#else
	return 400;
#endif
}

int Machine::screenLongLen()
{
#ifdef QWS
	QSize size = screensize();
	return MAX(size.height(), size.width());
#else
	return 400;
#endif
}

QString Machine::picsPath(QString file)
{
	if (screensize().height() <= 320) {
		if (file.compare("SDDeviceS.png") == 0) {
			file = "mountmon/sdcard.png";
		} else if (file.compare("myzaurus.png") == 0) {
			file = "slfolder.png";
		} else if (file.compare("MainDeviceS.png") == 0) {
			file = "myzaurus.png";
		} else if (file.compare("DocsIcon.png") == 0) {
			file = "slUnknown14.png";
		}

		return QString("/opt/Qtopia/pics/") + file;
	}
	return QString("/opt/Qtopia/pics144/") + file;
}
