/*
  mainwidget.cpp
  Copyright (C) 2008-2009 Tomohiro Masubuchi <bucchi@e-ml.jp>

  This file is part of qgmap.

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; If not, see <http://www.gnu.org/licenses/>.
*/

//#define DEBUG

#include "mainwidget.h"

#include <qwidget.h>
#include <qsizepolicy.h>
#include <stdio.h>
#include "qgmap.h"
#include "qgconf.h"
#include "version.h"

#include <qdialog.h>
#include <qdatetime.h>
#include <qmenubar.h>
#include <qpopupmenu.h>

#include "pos.h"

#include "gmap.h"
#include "centerpos.h"
#include "slider.h"
#include "marker.h"
#include "scale.h"
#include "gpsview.h"
#include "poi_view.h"
#include "centermarker.h"
#include "freehandregion.h"
#include "poiinfoview.h"
#include "mainmenu.h"

#include "help.h"
#include "info.h"

#include "mounter.h"

#include "mappathdialog.h"
#include "gammadialog.h"
#include "poi_dialog.h"

#ifndef QWS
#include <qlabel.h>
#endif
#ifdef QWS
#include <qcopchannel_qws.h>
#endif

#include "gpsmenu.h"

MainWidget::MainWidget( QWidget *parent, const char *name, WFlags fl) :
	LayeredBase(parent, name, fl)
{
	gmap = new GMap(this,"gmap");
	center = new CenterPos(this,"center");
	slider = new Slider(this,"slider");
	marker = new Marker(this,"marker");
	scale = new Scale(this,"scale");
	gpsview = new GPSView(this,"gpsview");
	poiview = new PoiView(this,"poiview");
	centermarker = new CenterMarker(this,"centermarker");
	freehand = new FreehandRegion(this,"freehand");

	help = new Help(this);
	info = new Info(this);
	poiinfo = new PoiInfoView(this);

	addWidget(gmap);
	addWidget(center);
	addWidget(slider);
	addWidget(marker);
	addWidget(scale);
	addWidget(gpsview);
	addWidget(poiview);
	addWidget(centermarker);
	addWidget(freehand);

#ifndef QWS
	setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
#else
	setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding));
#endif

#ifndef QWS
	label = new QLabel(this);
	label->setGeometry(640-16,640-16,16,16);
#endif
}

MainWidget::~MainWidget()
{
	delete gmap;
	delete center;
	delete slider;
	delete marker;
	delete scale;
	delete gpsview;
	delete centermarker;
	delete freehand;

	delete help;
	delete info;
	delete poiinfo;
}

void MainWidget::dispInfo(QString str)
{
	info->dispInfo(str);
}

void MainWidget::hideInfo()
{
	info->hide();
}

void MainWidget::dispPoiInfo(QPixmap const &icon, QString const &title,
							 QString const &desc, QString const &info)
{
	poiinfo->setIcon(icon);
	poiinfo->setTitle(title);
	poiinfo->setDesc(desc);
	poiinfo->setInfo(info);
	poiinfo->show();
}

void MainWidget::mousePressEvent( QMouseEvent *e )
{
	this->setFocus();

	if(help->isVisible()){
		help->hide();
		return;
	}
	if(poiinfo->isVisible()){
		poiinfo->hide();
		return;
	}

	LayeredBase::mousePressEvent(e);
}

void MainWidget::keyPressEvent ( QKeyEvent * e )
{
	if(help->isVisible()){
		help->hide();
		return;
	}
	if(poiinfo->isVisible()){
		poiinfo->hide();
		return;
	}

	switch(e->key()){
	case Key_H:
#ifndef QWS // for PC
	case Key_Question:
#endif
		help->show();
		return;

	case Key_Period:
		if(e->state() & ShiftButton){
			help->show();
			return;
		}
		break;
	}

	LayeredBase::keyPressEvent(e);
}

void MainWidget::paintEvent( QPaintEvent *e )
{
	LayeredBase::paintEvent(e);
	if(info->isVisible())
		info->repaint();
	if(help->isVisible())
		help->repaint();
	if(poiinfo->isVisible())
		poiinfo->repaint();
}

const Pos &MainWidget::getPosition(void)
{
	return center->getPosition();
}
