/*
  map.h
  Copyright (C) 2008-2009 Tomohiro Masubuchi <bucchi@e-ml.jp>

  This file is part of qgmap.

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __MAP_H__
#define __MAP_H__

#ifndef QWS
#define SAFE
#endif

#include <qpixmap.h>
#include <qimage.h>
#include <qobject.h>
#include <qlist.h>
#include <pthread.h>
#include "pos.h"
#include "pos_queue.h"
#include <stdio.h>
#include <qcache.h>

class MapItem;

struct map_result
{
	QString key;
	QImage *image;
};

class Map : public QObject
{
	Q_OBJECT;
  public:
	Map(QObject *parent);
	~Map();

	const QPixmap *getMap(Pos pos);
	void putMap(const QPixmap *p);
	void setPosition(const Pos &);
	void addItem(MapItem *item);
	void request(QString const &req, QString const &arg);

 private:
	QCache<QPixmap> *cache;

	pthread_t tid;
	bool thread_run;

	static void *thread_starter(void *);
	void thread(void);

	PosQueue pos_queue;

	pthread_mutex_t lock;
	pthread_cond_t cond_queue;

	bool is_processing;
	pthread_cond_t cond_process;

	int thread_counter;
	int qt_counter;

	void timerEvent(QTimerEvent *e);

	QPixmap loading;

	QList<MapItem> items;
#ifdef SAFE
	QList<QImage> result_img;
#endif

	Pos center;

  public slots:
	void flush();

  signals:
	void reload(bool);
	void updateMap();
	void configChanged(const QString &name, const QString &value);
};

#endif // __MAP_H__
