/*
  poi_icon.cpp
  Copyright (C) 2009 Tomohiro Masubuchi <bucchi@e-ml.jp>

  This file is part of qgmap.

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; If not, see <http://www.gnu.org/licenses/>.
*/

#include "poi_icon.h"
#include <assert.h>
#include <qfile.h>
#include <qpixmap.h>
#include <qimage.h>
#include <qbitmap.h>
#include <qpainter.h>
#include <qfile.h>
#include <qfileinfo.h>
#include <qcstring.h>

PoiIcon::PoiIcon()
{
}

bool PoiIcon::load(const char *filename)
{
	const char *img_format;

	img_format = QPixmap::imageFormat(filename);
	if (!img_format)
		return false;

	if (!icon.load(filename))
		return false;

	icon = icon.convertDepth(32);

	if (strcmp(img_format, "PNG") != 0)
		convertAlpha();

	return true;
}

QPixmap PoiIcon::getPixmap()
{
	QPixmap pix;
	pix.convertFromImage(icon);
	return pix;
}

QByteArray *PoiIcon::getPNGdata()
{
	return convertPNGdata(icon);
}

QByteArray *PoiIcon::convertPNGdata(const QPixmap &pix)
{
	QString tmpfile = "/tmp/tmpfile.png";

	if (!pix.save(tmpfile, "PNG")) {
		printf("PNG save error!!\n");
		return NULL;
	}

	QFile file(tmpfile);
	if (!file.open(IO_ReadOnly)) {
		printf("PNG open error!!\n");
		file.remove();
		return NULL;
	}

	uint size = QFileInfo(file).size();
	QByteArray *data = new QByteArray(size);

	if (!file.readBlock(data->data(), size)) {
		printf("PNG read error!!\n");
		delete data;
		data = NULL;
	}

	file.close();
	file.remove();

	return data;
}

QByteArray *PoiIcon::convertPNGdata(const QImage &img)
{
	QString tmpfile = "/tmp/tmpfile.png";

	if (!img.save(tmpfile, "PNG")) {
		printf("PNG save error!!\n");
		return NULL;
	}

	QFile file(tmpfile);
	if (!file.open(IO_ReadOnly)) {
		printf("PNG open error!!\n");
		file.remove();
		return NULL;
	}

	uint size = QFileInfo(file).size();
	QByteArray *data = new QByteArray(size);

	if (!file.readBlock(data->data(), size)) {
		printf("PNG read error!!\n");
		delete data;
		data = NULL;
	}

	file.close();
	file.remove();

	return data;
}

void PoiIcon::convertAlpha()
{
	int x, y;
	uint *scan;

	for (y = 0; y < icon.height(); y++) {
		scan = (uint *)icon.scanLine(y);
		for (x = 0; x < icon.width(); x++) {
			if (((*scan) & 0xffffff) != 0xff00ff)
				*scan = 0x00000000;
			scan++;
		}
	}
}
