/*
  poi_view.cpp
  Copyright (C) 2008-2009 Tomohiro Masubuchi <bucchi@e-ml.jp>

  This file is part of qgmap.

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; If not, see <http://www.gnu.org/licenses/>.
*/

//#define DEBUG
#include "qgmap.h"
#include "poi_view.h"
#include "mainwidget.h"
#include <qpixmap.h>
#include <qevent.h>
#include "poi_db.h"
#include <stdio.h>

PoiView::PoiView(LayeredBase *parent, const char *name) :
	LayeredWidget(parent, name)
{
	Enter();
	db = new PoiDb(g_db_poi);

	/* connect signals */
	connect(parent, SIGNAL(positionChanged(Pos &)),
			this, SLOT(setPosition(Pos &)));
	connect(this, SIGNAL(movePosition(Pos &)),
			parent, SIGNAL(movePosition(Pos &)));
}

bool PoiView::mouseClickEvent(QMouseEvent *ev)
{
	Enter();
	Pos pos = center;

	pos = pos.offset(ev->x() - this->width() / 2,
					 ev->y() - this->height() / 2);

	PoiDbItem *item = db->queryPoiItem(pos.getX(), pos.getY(), pos.getZoom());

	int x, y, icon_id, file_id;
	QString name, info;

	if (!item)
		return false;

	if (!item->next())
		return false;

	do {
		x = item->getX();
		y = item->getY();
		icon_id = item->getIconId();
		name = item->getName();
		info = item->getInfo();
		file_id = item->getFileId();
	} while (item->next());

	delete item;

	PoiDbFile *file = db->queryPoiFile(-1, file_id);
	if (!file)
		return false;

	if (!file->next())
		return false;

	MainWidget *main = (MainWidget *)parentWidget();
	main->dispPoiInfo(QPixmap(db->getPoiIcon(icon_id)),
					  name, info, file->getName());

	delete file;

	Pos p(x, y, 0);
	p.zoomTo(center.getZoom());
	emit movePosition(p);

	return false;
}

bool PoiView::keyPressEvent(QKeyEvent *e)
{
	UNUSED(e);
	return false;
}

void PoiView::showEvent()
{
	Enter();
	QWidget *parent = parentWidget();
	int width = parent->width();
	int height = parent->height();

	setGeometry(0, 0, width, height);
}

void PoiView::setPosition(Pos &center)
{
	Enter();
	this->center = center;
	this->center.normalize();
}
