/*
  sqlite.h
  Copyright (C) 2008-2009 Tomohiro Masubuchi <bucchi@e-ml.jp>

  This file is part of qgmap.

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __SQLITE_H__
#define __SQLITE_H__

#include <sqlite3.h>
#include <qstring.h>
#include <qcstring.h>

class SQLiteStatement;

class SQLite
{
  public:
	SQLite();
	~SQLite();

	int open(const char *filename);
	void close();
	int exec(const char *sql);
	SQLiteStatement *newQuery(const char *sql);

	int execOneColumn(const char *sql);

	static QString escape(QString str);

	void createFunction(const char *name, int args, void (*)(sqlite3_context *, int, sqlite3_value **));

  private:
	sqlite3 *db;
};

class SQLiteStatement
{
	friend class SQLite;
  public:
	SQLiteStatement();
	~SQLiteStatement();

	int bind(int index, const unsigned char *data, int size);
	int bind(int index, const QByteArray &data);
	int bind(int index, const char *string);
	int bind(int index, const QString &string);
	int bind(int index, double value);
	int bind(int index, sqlite3_int64 value);
	int bind(int index, int value);
	int bindNull(int index);
	int step();
	int reset();

	QByteArray getColumnBlob(int col);
	int getColumnInt(int col);
	double getColumnDouble(int col);
	QString getColumnText(int col);
	bool isColumnNull(int col);

	void printRow();

	int getRowCount();

  private:
	sqlite3_stmt *stmt;
};

#endif // __SQLITE_H__
